# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0128_remove_historicalsubjectvisit_clinic_services_other_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="bloodresultsfbc",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: FBC",
                "verbose_name_plural": "Blood Results: FBC",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsglu",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Glucose",
                "verbose_name_plural": "Blood Results: Glucose",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultshba1c",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: HbA1c",
                "verbose_name_plural": "Blood Results: HbA1c",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsins",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Insulin",
                "verbose_name_plural": "Blood Results: Insulin",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslft",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: LFT",
                "verbose_name_plural": "Blood Results: LFT",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslipid",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Lipids",
                "verbose_name_plural": "Blood Results: Lipids",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsrft",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: RFT",
                "verbose_name_plural": "Blood Results: RFT",
            },
        ),
        migrations.AlterModelOptions(
            name="cd4result",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "CD4 Result",
                "verbose_name_plural": "CD4 Results",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicalnote",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinical Note",
                "verbose_name_plural": "Clinical Note",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicalreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinical Review",
                "verbose_name_plural": "Clinical Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicalreviewbaseline",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinical Review: Baseline",
                "verbose_name_plural": "Clinical Review: Baseline",
            },
        ),
        migrations.AlterModelOptions(
            name="complicationsbaseline",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Complications: Baseline",
                "verbose_name_plural": "Complications: Baseline",
            },
        ),
        migrations.AlterModelOptions(
            name="complicationsfollowup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Complications: Followup",
                "verbose_name_plural": "Complications: Followup",
            },
        ),
        migrations.AlterModelOptions(
            name="concomitantmedication",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Concomitant Medication",
                "verbose_name_plural": "Concomitant Medication",
            },
        ),
        migrations.AlterModelOptions(
            name="dminitialreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Initial Review",
                "verbose_name_plural": "Diabetes Initial Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="dmmedicationadherence",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication Adherence (Diabetes)",
                "verbose_name_plural": "Medication Adherence (Diabetes)",
            },
        ),
        migrations.AlterModelOptions(
            name="dmreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Review",
                "verbose_name_plural": "Diabetes Review",
            },
        ),
        migrations.AlterModelOptions(
            name="drugrefilldm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Refill: Diabetes",
                "verbose_name_plural": "Drug Refills: Diabetes",
            },
        ),
        migrations.AlterModelOptions(
            name="drugrefillhiv",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Refill: HIV",
                "verbose_name_plural": "Drug Refills: HIV",
            },
        ),
        migrations.AlterModelOptions(
            name="drugrefillhtn",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Refill: Hypertension",
                "verbose_name_plural": "Drug Refills: Hypertension",
            },
        ),
        migrations.AlterModelOptions(
            name="drugsupplydm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Supply: Diabetes",
                "verbose_name_plural": "Drug Supply: Diabetes",
            },
        ),
        migrations.AlterModelOptions(
            name="drugsupplyhiv",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Supply: HIV",
                "verbose_name_plural": "Drug Supply: HIV",
            },
        ),
        migrations.AlterModelOptions(
            name="drugsupplyhtn",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Supply: Hypertension",
                "verbose_name_plural": "Drug Supply: Hypertension",
            },
        ),
        migrations.AlterModelOptions(
            name="eq5d3l",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
            },
        ),
        migrations.AlterModelOptions(
            name="familyhistory",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Family History and Knowledge",
                "verbose_name_plural": "Family History and Knowledge",
            },
        ),
        migrations.AlterModelOptions(
            name="glucose",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Glucose",
                "verbose_name_plural": "Glucose",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomics",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics",
                "verbose_name_plural": "Health Economics",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicsassets",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics: Assets",
                "verbose_name_plural": "Health Economics: Assets",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicshouseholdhead",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics: Household head",
                "verbose_name_plural": "Health Economics: Household head",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicsincome",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics: Income",
                "verbose_name_plural": "Health Economics: Income",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicspatient",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics: Patient",
                "verbose_name_plural": "Health Economics: Patient",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicsproperty",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics: Property",
                "verbose_name_plural": "Health Economics: Property",
            },
        ),
        migrations.AlterModelOptions(
            name="hivinitialreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "HIV Initial Review",
                "verbose_name_plural": "HIV Initial Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="hivmedicationadherence",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication Adherence (HIV)",
                "verbose_name_plural": "Medication Adherence (HIV)",
            },
        ),
        migrations.AlterModelOptions(
            name="hivreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "HIV Review",
                "verbose_name_plural": "HIV Review",
            },
        ),
        migrations.AlterModelOptions(
            name="htninitialreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hypertension Initial Review",
                "verbose_name_plural": "Hypertension Initial Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="htnmedicationadherence",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication Adherence (Hypertension)",
                "verbose_name_plural": "Medication Adherence (Hypertension)",
            },
        ),
        migrations.AlterModelOptions(
            name="htnreview",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hypertension Review",
                "verbose_name_plural": "Hypertension Review",
            },
        ),
        migrations.AlterModelOptions(
            name="icecapa",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "Overall quality of life (ICECAP-A V2)",
            },
        ),
        migrations.AlterModelOptions(
            name="locationupdate",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Location update",
                "verbose_name_plural": "Location updates",
            },
        ),
        migrations.AlterModelOptions(
            name="malariatest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Malaria Test",
                "verbose_name_plural": "Malaria Tests",
            },
        ),
        migrations.AlterModelOptions(
            name="medications",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medications",
                "verbose_name_plural": "Medications",
            },
        ),
        migrations.AlterModelOptions(
            name="nextappointment",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Next Appointment",
                "verbose_name_plural": "Next Appointments",
            },
        ),
        migrations.AlterModelOptions(
            name="otherbaselinedata",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Other Baseline Data",
                "verbose_name_plural": "Other Baseline Data",
            },
        ),
        migrations.AlterModelOptions(
            name="socialharms",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Social Harms",
                "verbose_name_plural": "Social Harms",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectrequisition",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject requisition",
                "verbose_name_plural": "Subject requisitions",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisit",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject visit",
                "verbose_name_plural": "Subject visits",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisitmissed",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Missed Visit Report",
                "verbose_name_plural": "Missed Visit Report",
            },
        ),
        migrations.AlterModelOptions(
            name="urinedipsticktest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Urine dipstick test",
                "verbose_name_plural": "Urine dipstick tests",
            },
        ),
        migrations.AlterModelOptions(
            name="urinepregnancy",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Urine pregnancy test",
                "verbose_name_plural": "Urine pregnancy tests",
            },
        ),
        migrations.AlterModelOptions(
            name="viralloadresult",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Viral Load Result",
                "verbose_name_plural": "Viral Load Results",
            },
        ),
        migrations.AlterModelOptions(
            name="vitals",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Vitals",
                "verbose_name_plural": "Vitals",
            },
        ),
    ]



# Generated by Django 4.2.5 on 2023-10-05 23:36

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("edc_next_appointment", "0002_infosources_extra_value"),
        ("edc_appointment", "0046_infosources"),
        ("intecomm_subject", "0119_auto_20231006_0220"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
    ]



from django.core.exceptions import ObjectDoesNotExist
from edc_identifier.identifier import Identifier
from edc_identifier.simple_identifier import SimpleUniqueIdentifier


class PatientLogIdentifier(SimpleUniqueIdentifier):
    name = "patient_log_identifier"
    template = "P{random_string}"
    random_string_length: int = 7


class FilingIdentifier(Identifier):
    name = "filing_identifier"
    identifier_pattern = r"^[0-9]{3}-\d+$"
    separator = "-"
    prefix = "F"

    def __init__(self, site_id: int = None, **kwargs):
        self.site_id = str(site_id)
        super().__init__(**kwargs)

    def next_identifier(self):
        """Sets the next identifier and updates the identifier model."""
        segment = self.remove_separator(self.identifier)[1:]
        if not segment or segment == "0":
            segment = int(f"{self.site_id}{'10000'}")
        segment = str(int(segment) + 1)
        self.identifier = f"{self.prefix}{segment[0:3]}{self.separator}{segment[3:]}"
        self.update_identifier_model()

    @property
    def last_identifier(self):
        """Returns the last identifier in the identifier model."""
        last_identifier = None
        opts = dict(
            identifier_type=self.name,
            identifier__istartswith=f"{self.prefix}{self.site_id}",
        )
        try:
            instance = (
                self.identifier_model_cls.objects.filter(**opts).order_by("identifier").last()
            )
        except AttributeError:
            pass
        else:
            if instance:
                last_identifier = instance.identifier
        return last_identifier

    def validate_identifier_pattern(self, *args, **kwargs):
        return True

    def update_identifier_model(self) -> bool:
        """Attempts to update identifier_model and returns True (or instance)
        if successful else False if identifier already exists.
        """
        try:
            self.identifier_model_cls.objects.get(identifier=self.identifier)
        except ObjectDoesNotExist:
            return self.identifier_model_cls.objects.create(
                identifier=self.identifier,
                identifier_type=self.name,
                identifier_prefix=self.identifier_prefix,
                device_id=self.device_id,
                site_id=self.site_id,
            )
        return False



# Generated by Django 4.1.2 on 2022-11-20 21:08

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("intecomm_lists", "0001_initial"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_screening", "0001_initial"),
        ("intecomm_group", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="patientgroupmeeting",
            name="patients",
            field=models.ManyToManyField(
                to="intecomm_screening.patientlog", verbose_name="Patients"
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="community_care_location",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_group.communitycarelocation",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="patient_group",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_group.patientgroup",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="patients",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_screening.patientlog",
                verbose_name="Membership",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="history_user",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="location_type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_lists.locationtypes",
            ),
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]



# Generated by Django 4.2.1 on 2023-05-24 03:03

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0047_healtheconomicsassets_cooking_fuel_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_currency",
            field=models.CharField(
                blank=True,
                choices=[
                    ("USD", "USD"),
                    ("GBP", "GBP"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Dont' know"),
                ],
                max_length=50,
                null=True,
                verbose_name="In what currency do you receive remittances?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Do you have additional sources of income not included above?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_other",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If YES additional sources, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_additional_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_additional_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_currency",
            field=models.CharField(
                blank=True,
                choices=[
                    ("USD", "USD"),
                    ("GBP", "GBP"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Dont' know"),
                ],
                max_length=50,
                null=True,
                verbose_name="In what currency do you receive remittances?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Do you have additional sources of income not included above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_other",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If YES additional sources, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_additional_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_additional_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-12-02 23:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0003_alter_historicalsocialharms_coworkers_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsocialharms",
            name="employment_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="employment_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="employment_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="employment_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="employment_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="healthcare_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="healthcare_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="healthcare_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="healthcare_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="healthcare_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="insurance_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="insurance_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="insurance_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="insurance_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="insurance_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact_description",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact_description",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="historicalsocialharms",
            name="other_service_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="employment_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="socialharms",
            name="employment_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="employment_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="employment_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="employment_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="healthcare_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="socialharms",
            name="healthcare_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="healthcare_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="healthcare_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="healthcare_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="insurance_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="socialharms",
            name="insurance_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="insurance_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="insurance_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="insurance_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact_description",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="NOT_APPLICABLE",
                max_length=25,
                verbose_name="... with your partner?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact_description",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact_help",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Would you like help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact_referal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Has the participant been referred for further help",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact_severity",
            field=models.CharField(
                choices=[
                    ("minor", "Minor"),
                    ("moderate", "Moderate"),
                    ("major", "Major"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Severity of impact",
            ),
        ),
        migrations.AddField(
            model_name="socialharms",
            name="other_service_impact_status",
            field=models.CharField(
                choices=[
                    ("resolved", "Resolved"),
                    ("ongoing", "Ongoing"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Status of impact",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="coworkers_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="family_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="friends_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="coworkers_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="family_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="friends_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your partner?",
            ),
        ),
    ]



from django.db import models
from edc_qareports.model_mixins import QaReportModelMixin
from edc_utils import get_utcnow


class MissingVlDrawDates(QaReportModelMixin, models.Model):
    report_model = models.CharField(
        max_length=50, default="intecomm_reports.missingvldrawdates"
    )

    created = models.DateTimeField(default=get_utcnow)

    baseline_date = models.DateField(null=True)

    visit_date = models.DateField(null=True)

    visit_code = models.FloatField(null=True)

    vl = models.IntegerField(null=True)

    objects = models.Manager()

    class Meta:
        db_table = "intecomm_reports_missingvldrawdates"
        verbose_name = "Viral load: Missing draw date"
        verbose_name_plural = "Viral load: Missing draw dates"



# Generated by Django 4.2.4 on 2023-08-23 01:13

import _socket
from django.db import migrations, models
import django_audit_fields.fields.hostname_modification_field
import edc_model.models.fields.date_estimated


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0008_alter_deathreporttmgsecond_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aefollowup",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhospitalization",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalhospitalization",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalhospitalization",
            name="discharged_date_estimated",
            field=edc_model.models.fields.date_estimated.IsDateEstimatedFieldNa(
                choices=[
                    ("N/A", "Not applicable"),
                    ("not_estimated", "No"),
                    ("D", "Yes, estimated the Day"),
                    ("MD", "Yes, estimated Month and Day"),
                    ("YMD", "Yes, estimated Year, Month and Day"),
                ],
                default="N/A",
                help_text="If the exact date is not known, please indicate which part of the date is estimated.",
                max_length=25,
                verbose_name="If YES, is this date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhospitalization",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhospitalization",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="hospitalization",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="hospitalization",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="hospitalization",
            name="discharged_date_estimated",
            field=edc_model.models.fields.date_estimated.IsDateEstimatedFieldNa(
                choices=[
                    ("N/A", "Not applicable"),
                    ("not_estimated", "No"),
                    ("D", "Yes, estimated the Day"),
                    ("MD", "Yes, estimated Month and Day"),
                    ("YMD", "Yes, estimated Year, Month and Day"),
                ],
                default="N/A",
                help_text="If the exact date is not known, please indicate which part of the date is estimated.",
                max_length=25,
                verbose_name="If YES, is this date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="hospitalization",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="hospitalization",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
    ]



# Generated by Django 4.2.10 on 2024-02-28 01:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_consent", "0023_alter_subjectconsent_managers"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalsubjectconsent",
            old_name="updates_versions",
            new_name="update_versions",
        ),
        migrations.RenameField(
            model_name="historicalsubjectconsenttz",
            old_name="updates_versions",
            new_name="update_versions",
        ),
        migrations.RenameField(
            model_name="historicalsubjectconsentug",
            old_name="updates_versions",
            new_name="update_versions",
        ),
        migrations.RenameField(
            model_name="subjectconsent",
            old_name="updates_versions",
            new_name="update_versions",
        ),
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                editable=False, max_length=50, null=True, verbose_name="Consent definition"
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectconsenttz",
            name="consent_definition_name",
            field=models.CharField(
                editable=False, max_length=50, null=True, verbose_name="Consent definition"
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectconsentug",
            name="consent_definition_name",
            field=models.CharField(
                editable=False, max_length=50, null=True, verbose_name="Consent definition"
            ),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                editable=False, max_length=50, null=True, verbose_name="Consent definition"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="version",
            field=models.CharField(
                editable=False,
                help_text="See 'consent definition' for consent versions by period.",
                max_length=10,
                verbose_name="Consent version",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsenttz",
            name="version",
            field=models.CharField(
                editable=False,
                help_text="See 'consent definition' for consent versions by period.",
                max_length=10,
                verbose_name="Consent version",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentug",
            name="version",
            field=models.CharField(
                editable=False,
                help_text="See 'consent definition' for consent versions by period.",
                max_length=10,
                verbose_name="Consent version",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="version",
            field=models.CharField(
                editable=False,
                help_text="See 'consent definition' for consent versions by period.",
                max_length=10,
                verbose_name="Consent version",
            ),
        ),
    ]



from django.db import models

from .model_mixins import BaseVlSummaryModelMixin


class VlSummary9m(BaseVlSummaryModelMixin):
    """A data management table to list expected VL results
    for baseline and endline.

    See class VlSummary. For example, to populate:
        vl_summary = VlSummary(endline_months=9, skip_update_dx=True)

    Populated in the modeladmin.get_queryset
    """

    report_model = models.CharField(max_length=50, default="intecomm_reports.vlsummary6m")

    class Meta:
        verbose_name = "Viral load summary (endline >= 9m)"
        verbose_name_plural = "Viral load summary (endline >= 9m)"


class VlSummary6m(BaseVlSummaryModelMixin):
    """A data management table to list expected VL results
    for baseline and endline.

    See class VlSummary. For example, to populate:
        vl_summary = VlSummary(endline_months=6, skip_update_dx=True)

    Populated in the modeladmin.get_queryset
    """

    report_model = models.CharField(max_length=50, default="intecomm_reports.vlsummary9m")

    class Meta:
        verbose_name = "Viral load summary (endline >= 6m)"
        verbose_name_plural = "Viral load summary (endline >= 6m)"



# Generated by Django 5.0.4 on 2024-04-16 11:24

import intecomm_subject.models.fields.expense_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0171_alter_careseekinga_travel_time_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINCOST1",
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINFOODCOST1",
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINCOST1",
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINFOODCOST1",
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0017_alter_subjectconsent_options_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_co_modifie_45691e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_co_user_mo_5935e6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectreconsent",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_co_modifie_fddd38_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectreconsent",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_co_user_mo_4da839_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("subject_identifier", "version"),
                name="intecomm_consent_subjectconsent_subj_ver_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials", "version"),
                name="intecomm_consent_subjectconsent_legal_name_uniq",
            ),
        ),
    ]



from __future__ import annotations

from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_sites.admin import SiteModelAdminMixin

from ..admin_site import intecomm_screening_admin
from ..forms import ConsentRefusalForm
from ..models import ConsentRefusal
from .modeladmin_mixins import (
    BaseModelAdminMixin,
    RedirectAllToPatientLogModelAdminMixin,
)


@admin.register(ConsentRefusal, site=intecomm_screening_admin)
class ConsentRefusalAdmin(
    SiteModelAdminMixin,
    RedirectAllToPatientLogModelAdminMixin,
    BaseModelAdminMixin,
):
    form = ConsentRefusalForm
    show_object_tools = True
    list_per_page = 5
    ordering = ("site__id", "screening_identifier")

    fieldsets = (
        [
            None,
            {
                "fields": (
                    "screening_identifier",
                    "report_datetime",
                    "reason",
                    "other_reason",
                )
            },
        ],
        (
            "Screening",
            {"classes": ("collapse",), "fields": ("subject_screening",)},
        ),
        audit_fieldset_tuple,
    )

    list_display = (
        "subject_screening",
        "report_datetime",
        "reason",
        "user_created",
        "created",
    )

    list_filter = ("report_datetime", "subject_screening__gender", "reason")

    search_fields = (
        "screening_identifier",
        "subject_screening__hospital_identifier",
        "subject_screening__initials",
    )

    radio_fields = {
        "reason": admin.VERTICAL,
    }

    readonly_fields = ("subject_screening",)



from __future__ import annotations

from typing import TYPE_CHECKING, Type

from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple

from ..admin_site import intecomm_subject_admin
from ..forms import HivReviewForm
from ..models import HivReview
from .fieldsets import care_delivery_fieldset_tuple
from .list_filters import VlStatusListFilter
from .modeladmin_mixins import CrfModelAdmin

if TYPE_CHECKING:
    from django.contrib.admin import SimpleListFilter


@admin.register(HivReview, site=intecomm_subject_admin)
class HivReviewAdmin(CrfModelAdmin):
    form = HivReviewForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        care_delivery_fieldset_tuple,
        (
            "Anti-retroviral therapy (ART)",
            {
                "fields": (
                    "rx_init",
                    "rx_init_date",
                    "rx_init_ago",
                )
            },
        ),
        (
            "Monitoring",
            {
                "fields": (
                    "has_vl",
                    "drawn_date",
                    "vl",
                    "vl_quantifier",
                ),
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "rx_init": admin.VERTICAL,
        "care_delivery": admin.VERTICAL,
        "crf_status": admin.VERTICAL,
        "dx": admin.VERTICAL,
        "has_vl": admin.VERTICAL,
        "vl_quantifier": admin.VERTICAL,
    }

    @admin.display(description="VL resulted", ordering="has_vl")
    def vl_status(self, obj):
        return obj.has_vl

    def get_list_filter(self, request) -> tuple[str | Type[SimpleListFilter], ...]:
        list_filters = super().get_list_filter(request)
        list_filters = list(list_filters) or []
        list_filters.insert(4, VlStatusListFilter)
        return tuple(list_filters)

    def get_list_display(self, request) -> tuple[str, ...]:
        list_display = super().get_list_display(request)
        list_display = list(list_display) or []
        list_display.insert(4, "vl_status")
        return tuple(list_display)



# Generated by Django 5.0.4 on 2024-04-15 17:45

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations

import intecomm_subject.models.fields.duration_field
import intecomm_subject.models.fields.expense_field
import intecomm_subject.models.fields.income_field


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_subject", "0169_alter_bloodresultsins_fasting_duration_str_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="careseekinga",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="care_visit_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekinga",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekingb",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekingb",
            name="care_visit_lost_income",
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FACMP1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during today’s visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FFACTIME1",
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_lost_income",
            field=intecomm_subject.models.fields.income_field.IncomeField(
                blank=True,
                metadata="FPAID1",
                null=True,
                verbose_name="How much would you have made in cash or in-kind for a day’s work?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFOODCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_dm",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTDM1",
                verbose_name="How much was spent on Diabetes medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_hiv",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHIV1", verbose_name="How much was spent on HIV medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_htn",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHTN1",
                verbose_name="How much was spent on Hypertension medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_other",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTOTHER1",
                verbose_name="How much was spent on OTHER medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FACTIVITY1",
                verbose_name="If you were not attending the visit today, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_time",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FTRATIME1", verbose_name="How long did it take you to reach here?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="wait_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWAITIME1", verbose_name="How much time did you spend waiting?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="with_hcw_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWORKTIME1",
                verbose_name="How much time did you spend during the consultation (i.e. time spent with the healthcareworker)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FOUTACMP1",
                to="intecomm_lists.accompanied",
                verbose_name="Who accompanied you to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTIME1",
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="food_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFOODCOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="ill_month",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                metadata="FILLMONTH1",
                verbose_name="Other than today’s visit, and thinking about the past 3 months, did you need to make any routine visits or were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_prescribed",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FOUTMED1",
                verbose_name="Were you prescribed any medicines during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                blank=True,
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Money received from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Money received from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FOUTSOURCE",
                related_name="%(app_label)s_money_sources_related",
                related_query_name="%(app_label)s_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported in the past 3 months, and excluding today’s visit, what were the source(s) of payment for all these expenses?  ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="no_seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("not_necessary", "Did not think it was necessary "),
                    ("recovered", "Recovered before I could go "),
                    (
                        "home_remedy",
                        "Home remedy given by family member, relatives, neighbours ",
                    ),
                    ("too_expensive", "Too expensive "),
                    ("no_time", "Wanted to but could not find time"),
                    ("no_transport", "There was no one to take me"),
                    ("facility_too_far", "The health facility is too far/ not easy to reach "),
                    ("hcw_unavailable", "Health care practitioner mostly unavailable "),
                    ("med_problems", "Taking medicines caused problems"),
                    (
                        "hcw_confusing",
                        "Do not understand what the healthcare practitioner says ",
                    ),
                    ("hcw_incompetent", "Practitioner is not competent in their work "),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If NO, STOP and SAVE form",
                max_length=25,
                metadata="FNOSEEK1",
                verbose_name="If no, why did you not make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you make the visit, seek advice or treatment (public facility, local pharmacy, traditional doctor etc)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("comm_health_centre", "Community health centre/health post"),
                    ("gov_dispensary", "Government dispensary"),
                    ("phc", "Primary health care center (PHC)"),
                    ("private_clinic", "Private clinic"),
                    ("ngo", "NGO clinic"),
                    ("public_hospital", "Public Hospital"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("hcw_home", "Any healthcare practitioner’s home"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKFAC1",
                verbose_name="If yes, where did you make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_requested",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="for example, blood pressure, viral load, glucose etc.",
                max_length=25,
                metadata="FOUTTEST1",
                verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTRACOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTRATIME1", verbose_name="How long did it take you to get there?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_method",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FOUTTRA1",
                to="intecomm_lists.travelmethods",
                verbose_name="Thinking about your last/most recent visit, how did you travel to the visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FACMP1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during today’s visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FFACTIME1",
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_lost_income",
            field=intecomm_subject.models.fields.income_field.IncomeField(
                blank=True,
                metadata="FPAID1",
                null=True,
                verbose_name="How much would you have made in cash or in-kind for a day’s work?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFOODCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_dm",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTDM1",
                verbose_name="How much was spent on Diabetes medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_hiv",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHIV1", verbose_name="How much was spent on HIV medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_htn",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHTN1",
                verbose_name="How much was spent on Hypertension medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_other",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTOTHER1",
                verbose_name="How much was spent on OTHER medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FACTIVITY1",
                verbose_name="If you were not attending the visit today, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_time",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FTRATIME1", verbose_name="How long did it take you to reach here?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="wait_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWAITIME1", verbose_name="How much time did you spend waiting?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="with_hcw_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWORKTIME1",
                verbose_name="How much time did you spend during the consultation (i.e. time spent with the healthcareworker)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTIME1",
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="food_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFOODCOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="ill_month",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                metadata="FILLMONTH1",
                verbose_name="Other than today’s visit, and thinking about the past 3 months, did you need to make any routine visits or were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_prescribed",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FOUTMED1",
                verbose_name="Were you prescribed any medicines during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                blank=True,
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Money received from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Money received from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="no_seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("not_necessary", "Did not think it was necessary "),
                    ("recovered", "Recovered before I could go "),
                    (
                        "home_remedy",
                        "Home remedy given by family member, relatives, neighbours ",
                    ),
                    ("too_expensive", "Too expensive "),
                    ("no_time", "Wanted to but could not find time"),
                    ("no_transport", "There was no one to take me"),
                    ("facility_too_far", "The health facility is too far/ not easy to reach "),
                    ("hcw_unavailable", "Health care practitioner mostly unavailable "),
                    ("med_problems", "Taking medicines caused problems"),
                    (
                        "hcw_confusing",
                        "Do not understand what the healthcare practitioner says ",
                    ),
                    ("hcw_incompetent", "Practitioner is not competent in their work "),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If NO, STOP and SAVE form",
                max_length=25,
                metadata="FNOSEEK1",
                verbose_name="If no, why did you not make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you make the visit, seek advice or treatment (public facility, local pharmacy, traditional doctor etc)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("comm_health_centre", "Community health centre/health post"),
                    ("gov_dispensary", "Government dispensary"),
                    ("phc", "Primary health care center (PHC)"),
                    ("private_clinic", "Private clinic"),
                    ("ngo", "NGO clinic"),
                    ("public_hospital", "Public Hospital"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("hcw_home", "Any healthcare practitioner’s home"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKFAC1",
                verbose_name="If yes, where did you make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_requested",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="for example, blood pressure, viral load, glucose etc.",
                max_length=25,
                metadata="FOUTTEST1",
                verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="travel_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTRACOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="travel_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTRATIME1", verbose_name="How long did it take you to get there?"
            ),
        ),
    ]



from edc_consent.consent_definition import ConsentDefinition
from edc_consent.site_consents import site_consents
from edc_constants.constants import FEMALE, MALE
from edc_protocol.research_protocol_config import ResearchProtocolConfig


def opts() -> dict:
    return dict(
        version="1",
        start=ResearchProtocolConfig().study_open_datetime,
        end=ResearchProtocolConfig().study_close_datetime,
        age_min=18,
        age_is_adult=18,
        age_max=110,
        gender=[MALE, FEMALE],
    )


cdef_tz_v1 = ConsentDefinition(
    proxy_model="intecomm_consent.subjectconsenttz",
    country="tanzania",
    **opts(),
)
cdef_ug_v1 = ConsentDefinition(
    proxy_model="intecomm_consent.subjectconsentug",
    country="uganda",
    **opts(),
)

site_consents.register(cdef_tz_v1)
site_consents.register(cdef_ug_v1)



# Generated by Django 4.2.1 on 2023-07-05 02:16

import django.db.models.deletion
import edc_screening.model_mixins.screening_model_mixin
import edc_sites.models
from django.db import migrations, models

import intecomm_screening.model_mixins.patient_call_model_mixin
import intecomm_screening.models.health_talk_log
import intecomm_screening.models.patient_log


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0041_auto_20230702_1548"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="healthfacility",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Health Facility",
                "verbose_name_plural": "Health Facilities",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalklog",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Health talk log",
                "verbose_name_plural": "Health talk logs",
            },
        ),
        migrations.AlterModelOptions(
            name="idenfifierformat",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Idenfifier format",
                "verbose_name_plural": "Idenfifier formats",
            },
        ),
        migrations.AlterModelOptions(
            name="patientlog",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient Log",
                "verbose_name_plural": "Patient Log",
            },
        ),
        migrations.AlterModelOptions(
            name="patientlogreportprinthistory",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
            },
        ),
        migrations.AlterModelManagers(
            name="healthtalklog",
            managers=[
                ("objects", intecomm_screening.models.health_talk_log.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="patientcall",
            managers=[
                (
                    "objects",
                    intecomm_screening.model_mixins.patient_call_model_mixin.Manager(),
                ),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="patientlog",
            managers=[
                ("objects", intecomm_screening.models.patient_log.PatientLogManager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="subjectscreening",
            managers=[
                (
                    "objects",
                    edc_screening.model_mixins.screening_model_mixin.ScreeningManager(),
                ),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]



import pandas as pd
from django.apps import apps as django_apps
from edc_constants.constants import YES
from edc_pdutils.dataframes import get_crf


def get_missing_drawn_dates_df(model: str | None = None):
    # "intecomm_reports.missingvldrawdates"
    df_review = get_crf(
        "intecomm_subject.hivreview", subject_visit_model="intecomm_subject.subjectvisit"
    )
    df_review["baseline_date"] = pd.to_datetime(df_review["baseline_datetime"]).dt.date
    df_review["baseline_date"] = pd.to_datetime(df_review["baseline_date"])
    df_review["visit_date"] = pd.to_datetime(df_review["visit_datetime"]).dt.date
    df_review["visit_date"] = pd.to_datetime(df_review["visit_date"])

    df_missing_drawn_date2 = df_review[
        (df_review["has_vl"] == YES) & (df_review["drawn_date"].isna())
    ][
        [
            "subject_identifier",
            "site",
            "baseline_date",
            "visit_date",
            "visit_code",
            "vl",
            "drawn_date",
        ]
    ]
    df_missing_drawn_date2.reset_index()

    df_initial = get_crf(
        "intecomm_subject.hivinitialreview",
        subject_visit_model="intecomm_subject.subjectvisit",
    )
    df_initial["baseline_date"] = pd.to_datetime(df_initial["baseline_datetime"]).dt.date
    df_initial["baseline_date"] = pd.to_datetime(df_initial["baseline_date"])
    df_initial["visit_date"] = pd.to_datetime(df_initial["visit_datetime"]).dt.date
    df_initial["visit_date"] = pd.to_datetime(df_initial["visit_date"])

    df_missing_drawn_date1 = df_initial[
        (df_initial["has_vl"] == YES) & (df_initial["drawn_date"].isna())
    ][
        [
            "subject_identifier",
            "site",
            "baseline_date",
            "visit_date",
            "visit_code",
            "vl",
            "drawn_date",
        ]
    ]
    df_missing_drawn_date1.reset_index()

    df_missing_drawn_date = pd.concat([df_missing_drawn_date1, df_missing_drawn_date2])
    df_missing_drawn_date = df_missing_drawn_date.rename(columns={"site": "site_id"})
    df = df_missing_drawn_date.sort_values(["subject_identifier", "visit_code"])
    df.reset_index(drop=True)

    # refresh model class
    model_cls = django_apps.get_model(model)
    model_cls.objects.all().delete()
    model_cls.objects.bulk_create(
        model_cls(
            subject_identifier=row["subject_identifier"],
            site_id=row["site_id"],
            baseline_date=(None if pd.isna(row["baseline_date"]) else row["baseline_date"]),
            visit_date=(None if pd.isna(row["visit_date"]) else row["visit_date"]),
            visit_code=(None if pd.isna(row["visit_code"]) else row["visit_code"]),
            vl=(None if pd.isna(row["vl"]) else row["vl"]),
        )
        for _, row in df.iterrows()
    )



# Generated by Django 4.2.3 on 2023-08-03 03:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0075_auto_20230803_0459"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            old_name="hoh_religion",
            new_name="hoh_religion_old",
        ),
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            old_name="hoh_religion",
            new_name="hoh_religion_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicspatient",
            old_name="pat_religion",
            new_name="pat_religion_old",
        ),
        migrations.RenameField(
            model_name="healtheconomicspatient",
            old_name="pat_religion",
            new_name="pat_religion_old",
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-26 19:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0003_diagnoses_baseline"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="diagnoses",
            name="baseline",
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="baseline_182d",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (182d before baseline)",
            ),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="baseline_6m",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (6m before baseline)",
            ),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_baseline_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_baseline_value",
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_endline_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_endline_value",
            field=models.IntegerField(null=True),
        ),
    ]



# Generated by Django 4.2.10 on 2024-03-07 18:57

from django.db import migrations, models
import edc_model.models.fields.other_charfield
import edc_model_fields.fields.custom_django_fields


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("edc_he", "0007_remove_education_edc_he_educ_name_64c0c9_idx_and_more"),
        ("intecomm_subject", "0149_alter_bloodresultsfbc_consent_model_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekinga",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FTODSOURCE",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported for today’s visit, what were the source(s) of payment for all these expenses?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FINSOURCE",
                related_name="%(app_label)s_inpatient_money_sources_related",
                related_query_name="%(app_label)s_inpatient_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="What were the source(s) of payment for all these expenses for your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FOUTSOURCE",
                related_name="%(app_label)s_money_sources_related",
                related_query_name="%(app_label)s_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported in the past 3 months, and excluding today’s visit, what were the source(s) of payment for all these expenses?  ",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="complications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If Yes, complete the 'Complications' CRF",
                max_length=15,
                verbose_name="Since last seen, has the patient had any complications",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_dm_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (DM)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_dm_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_hiv_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (HIV)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_hiv_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_htn_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...(HTN)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_htn_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_other_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_other_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="transport_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other reason', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_insurance",
            field=models.ManyToManyField(
                help_text="Not applicable if patient is head of household",
                related_name="+",
                to="edc_he.insurancetypes",
                verbose_name="Household head’s health insurance and 'club' status ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="complications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If Yes, complete the 'Complications' CRF",
                max_length=15,
                verbose_name="Since last seen, has the patient had any complications",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_dm_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (DM)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_dm_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_hiv_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (HIV)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_hiv_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_htn_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...(HTN)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_htn_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_other_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_other_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="transport_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other reason', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Diabetes.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Diabetes medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_hiv",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for HIV infection.",
                max_length=25,
                verbose_name="Is the patient filling / refilling HIV medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Hypertension.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Hypertension medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Diabetes.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Diabetes medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_hiv",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for HIV infection.",
                max_length=25,
                verbose_name="Is the patient filling / refilling HIV medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Hypertension.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Hypertension medications?",
            ),
        ),
    ]



from django.db import models
from django_db_views.db_view import DBView
from edc_qareports.model_mixins import QaReportModelMixin
from edc_utils import get_utcnow

from .view_definition import get_view_definition


class Vl(QaReportModelMixin, DBView):
    """A data management table with details of each HIV participant's
    viral load.
    """

    report_model = models.CharField(max_length=50, default="intecomm_reports.vl")

    created = models.DateTimeField(default=get_utcnow)

    vl_value = models.IntegerField(null=True)

    baseline_date = models.DateField(null=True)

    vl_date = models.DateField(null=True)

    m = models.IntegerField(verbose_name="months", null=True)

    view_definition = get_view_definition()

    class Meta:
        managed = False
        db_table = "intecomm_reports_vl_view"
        verbose_name = "Viral loads"
        verbose_name_plural = "Viral loads"



from django.core.management import BaseCommand

from intecomm_subject.utils import recalculate_dx_calculated_date


class Command(BaseCommand):
    def __init__(self, **kwargs):
        self.site_ids: list[int] = []
        super().__init__(**kwargs)

    def handle(self, *args, **options):
        recalculate_dx_calculated_date()
